==> syncope-2.0.12-source-release.zip: syncope-2.0.12/core/provisioning-api/src/main/java/org/apache/syncope/core/provisioning/api/pushpull/ProvisioningActions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.provisioning.api.pushpull;

import org.quartz.JobExecutionException;

public interface ProvisioningActions {

    /**
     * Action to be executed before to start the provisioning (push / pull) task execution.
     *
     * @param profile provisioning profile
     * @throws JobExecutionException in case of generic failure
     */
    void beforeAll(final ProvisioningProfile<?, ?> profile) throws JobExecutionException;

    /**
     * Action to be executed after the provisioning (push / pull) task completion.
     *
     * @param profile provisioning profile
     * @throws JobExecutionException in case of generic failure
     */
    void afterAll(final ProvisioningProfile<?, ?> profile) throws JobExecutionException;
}

==> syncope-2.0.14-source-release.zip: syncope-2.0.14/core/provisioning-api/src/main/java/org/apache/syncope/core/provisioning/api/pushpull/ProvisioningActions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.provisioning.api.pushpull;

import org.quartz.JobExecutionException;

public interface ProvisioningActions {

    /**
     * Action to be executed before to start the provisioning (push / pull) task execution.
     *
     * @param profile provisioning profile
     * @throws JobExecutionException in case of generic failure
     */
    void beforeAll(ProvisioningProfile<?, ?> profile) throws JobExecutionException;

    /**
     * Action to be executed after the provisioning (push / pull) task completion.
     *
     * @param profile provisioning profile
     * @throws JobExecutionException in case of generic failure
     */
    void afterAll(ProvisioningProfile<?, ?> profile) throws JobExecutionException;
}
